<?php
# ***** BEGIN LICENSE BLOCK *****
# This is Auto Backup, a plugin for DotClear. 
# Copyright (c) 2005 k-net. All rights reserved.
#
# DotClear is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
# 
# DotClear is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with DotClear; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
#
# ***** END LICENSE BLOCK *****

$this->registerModule(
	/* Name */			"Auto Backup",
	/* Description*/		"Make backups automatically",
	/* Author */			"k-net",
	/* Version */			'1.0.0',
	/* Permissions */		'usage,contentadmin'
);


class autoBackup {
	
	function getConfig() {
		
		global $core;
		
		if (!$core->blog->settings->autobackup_config) {
			$config = array(
				'lastbackup' => array('date' => 0, 'file' => ''),
				'backuptype' => 'full',
				'backupblogid' => 'default',
				'interval' => 3600*24,
				'repository' => $core->blog->public_path,
				'deleteprevbackup' => false,
			);
			self::setConfig($config);
			return $config;
		} else {
			return unserialize($core->blog->settings->autobackup_config);
		}
	}
	
	function setConfig($config) {
		
		global $core;
		
		$core->blog->settings->setNamespace('autobackup');
		$core->blog->settings->put('autobackup_config',serialize($config),'string');
		$core->blog->triggerBlog();
	}
	
	function check() {
		
		global $core;
		 
		$config = self::getConfig();
		
		if ($config['interval'] > 0 && ($config['lastbackup']['date'] + $config['interval'] <= time())) {
			
			$backupname = ($config['backuptype'] != 'full' ? $config['backupblogid'] : 'blog').'-backup-'.date('Ymd-H\hi').'.txt';
			
			if (($config['backuptype'] == 'full' && self::backup_full($config['repository'].'/'.$backupname))
			|| ($config['backuptype'] != 'full' && $config['backupblogid'] == $core->blog->id && self::backup_blog($config['repository'].'/'.$backupname, $config['backupblogid']))) {
				if ($config['deleteprevbackup'] && is_file($config['repository'].'/'.$config['lastbackup']['file'])) {
					@unlink($config['repository'].'/'.$config['lastbackup']['file']);
				}
				$config['lastbackup']['date'] = time();
				$config['lastbackup']['file'] = $backupname;
				self::setConfig($config);
			}
		}
	}
	                                                                                                            
	function backup_full($file) {
		
		require_once dirname(__FILE__).'/../importExport/class.db.export.php';
		
		global $core;
		
		if ((is_file($file) && is_writable($file)) || (!file_exists($file) && is_writable(dirname($file)))) {
			
			$exp = new dbExport($core->con,$file,$core->prefix);
			
			fwrite($exp->fp,'///DOTCLEAR|'.DC_VERSION."|full\n");
			$exp->exportTable('blog');
			$exp->exportTable('category');
			$exp->exportTable('link');
			$exp->exportTable('setting');
			$exp->exportTable('user');
			$exp->exportTable('permissions');
			$exp->exportTable('post');
			$exp->exportTable('media');
			$exp->exportTable('post_media');
			$exp->exportTable('log');
			$exp->exportTable('ping');
			$exp->exportTable('comment');
			$exp->exportTable('spamrule');
			$exp->exportTable('version');
			
			# --BEHAVIOR-- exportFull
			$core->callBehavior('exportFull',$core,$exp);
			
			return true;
		} else {
			return false;
		}
	}
	
	function backup_blog($file, $blog_id) {
		
		require_once dirname(__FILE__).'/../importExport/class.db.export.php';
		
		global $core;
		
		if ($blog_id != $core->blog->id) {
			return false;
		}
		
		if ((is_file($file) && is_writable($file)) || (!file_exists($file) && is_writable(dirname($file)))) {
			
			$exp = new dbExport($core->con,$file,$core->prefix);
			
			fwrite($exp->fp,'///DOTCLEAR|'.DC_VERSION."|single\n");
			$exp->export('category',
				'SELECT * FROM '.$core->prefix.'category '.
				"WHERE blog_id = '".$blog_id."'"
			);
			$exp->export('link',
				'SELECT * FROM '.$core->prefix.'link '.
				"WHERE blog_id = '".$blog_id."'"
			);
			$exp->export('setting',
				'SELECT * FROM '.$core->prefix.'setting '.
				"WHERE blog_id = '".$blog_id."'"
			);
			$exp->export('post',
				'SELECT * FROM '.$core->prefix.'post '.
				"WHERE blog_id = '".$blog_id."'"
			);
			$exp->export('media',
				'SELECT * FROM '.$core->prefix."media WHERE media_path = '".
				$core->con->escape($core->blog->settings->public_path)."'"
			);
			$exp->export('post_media',
				'SELECT media_id, M.post_id '.
				'FROM '.$core->prefix.'post_media M, '.$core->prefix.'post P '.
				'WHERE P.post_id = M.post_id '.
				"AND P.blog_id = '".$blog_id."'"
			);
			$exp->export('ping',
				'SELECT ping.post_id, ping_url, ping_dt '.
				'FROM '.$core->prefix.'ping ping, '.$core->prefix.'post P '.
				'WHERE P.post_id = ping.post_id '.
				"AND P.blog_id = '".$blog_id."'"
			);
			$exp->export('comment',
				'SELECT C.* '.
				'FROM '.$core->prefix.'comment C, '.$core->prefix.'post P '.
				'WHERE P.post_id = C.post_id '.
				"AND P.blog_id = '".$blog_id."'"
			);
			
			# --BEHAVIOR-- exportSingle
			$core->callBehavior('exportSingle',$core,$exp,$blog_id);
			
			return true;
		} else {
			return false;
		}
	}
	
}

autoBackup::check();

?>